@@ -20,17 +20,21 @@ GATEWAY_URI_QUERYSTRING = "?callname=%(call_name)s&siteid=%(site_id)s&appid=%(ap
 
 
 class EbaySuds(object):
-    def __init__(self, wsdl_url=WSDL_URL, **kwargs):
+    def __init__(self, wsdl_url=WSDL_URL, sandbox=False, **kwargs):
         self.sudsclient = Client(wsdl_url, cachingpolicy=1, transport=WellBehavedHttpTransport())
         self.site_id = kwargs.get('site_id') or ebaysuds_config.get('site', 'site_id')
-        self.app_id = kwargs.get('app_id') or ebaysuds_config.get('keys', 'app_id')
+        if sandbox:
+            key_section = 'sandbox_keys'
+        else:
+            key_section = 'production_keys'
+        self.app_id = kwargs.get('app_id') or ebaysuds_config.get(key_section, 'app_id')
 
         # do the authentication ritual
         credentials = self.sudsclient.factory.create('RequesterCredentials')
         credentials.eBayAuthToken = kwargs.get('token') or ebaysuds_config.get('auth', 'token')
         credentials.Credentials.AppId = self.app_id
         credentials.Credentials.DevId = kwargs.get('dev_id') or ebaysuds_config.get('keys', 'dev_id')
-        credentials.Credentials.AuthCert = kwargs.get('cert_id') or ebaysuds_config.get('keys', 'cert_id')
+        credentials.Credentials.AuthCert = kwargs.get('cert_id') or ebaysuds_config.get(key_section, 'cert_id')
         self.sudsclient.set_options(soapheaders=credentials)
         
         # find current API version from the WSDL
